@@ -6,13 +6,18 @@ homedir = os.environ['HOME']
 default_cfg = StringIO("""
 [visual]
 background = black
-size = 800
+foreground = white
+height = 800
+width = 800
 cortex = classic
 default_view = lateral
 
 [overlay]
 min_thresh = 2.0
 max_thresh = robust_max
+
+[options]
+logging_level = INFO
 """)
 
 config = ConfigParser.ConfigParser()
